pub struct RequestBuilder<'a> { /* private fields */ }
Options for an individual Request.

One of these will be built for you if you use one of the convenience methods, such as get(), post(), etc.

Implementations

Set a request body to be sent.

Add additional headers to the request.

Add an individual new header to the request.

Execute this request and receive a Response back.