pub enum Error {
Method,
Uri(ParseError),
Version,
Header,
TooLarge,
Status,
Io(IoError),
Ssl(Box<dyn StdError + Send + Sync>),
Utf8(Utf8Error),
// some variants omitted
}Expand description
A set of errors that can occur parsing HTTP streams.
Variants
Method
An invalid Method, such as GE,T.
Uri(ParseError)
An invalid RequestUri, such as exam ple.domain.
Version
An invalid HttpVersion, such as HTP/1.1
Header
An invalid Header.
TooLarge
A message head is too large to be reasonable.
Status
An invalid Status, such as 1337 ELITE.
Io(IoError)
An io::Error that occurred while trying to read or write to a network stream.
Ssl(Box<dyn StdError + Send + Sync>)
An error from a SSL library.
Utf8(Utf8Error)
Parsing a field as string failed