pub enum Pragma {
NoCache,
Ext(String),
}Expand description
The Pragma header defined by HTTP/1.0.
The “Pragma” header field allows backwards compatibility with HTTP/1.0 caches, so that clients can specify a “no-cache” request that they will understand (as Cache-Control was not defined until HTTP/1.1). When the Cache-Control header field is also present and understood in a request, Pragma is ignored. In HTTP/1.0, Pragma was defined as an extensible field for implementation-specified directives for recipients. This specification deprecates such extensions to improve interoperability.
Spec: https://tools.ietf.org/html/rfc7234#section-5.4
Examples
use cogo_http::header::{Headers, Pragma};
let mut headers = Headers::new();
headers.set(Pragma::NoCache);use cogo_http::header::{Headers, Pragma};
let mut headers = Headers::new();
headers.set(Pragma::Ext("foobar".to_owned()));Variants
NoCache
Corresponds to the no-cache value.
Ext(String)
Every value other than no-cache.