Enum cogo_http::header::ReferrerPolicy
source · [−]pub enum ReferrerPolicy {
NoReferrer,
NoReferrerWhenDowngrade,
SameOrigin,
Origin,
OriginWhenCrossOrigin,
UnsafeUrl,
StrictOrigin,
StrictOriginWhenCrossOrigin,
}Expand description
Referrer-Policy header, part of
Referrer Policy
The Referrer-Policy HTTP header specifies the referrer
policy that the user agent applies when determining what
referrer information should be included with requests made,
and with browsing contexts created from the context of the
protected resource.
ABNF
Referrer-Policy: 1#policy-token
policy-token = "no-referrer" / "no-referrer-when-downgrade"
/ "same-origin" / "origin"
/ "origin-when-cross-origin" / "unsafe-url"Example values
no-referrer
Example
use cogo_http::header::{Headers, ReferrerPolicy};
let mut headers = Headers::new();
headers.set(ReferrerPolicy::NoReferrer);Variants
NoReferrer
no-referrer
NoReferrerWhenDowngrade
no-referrer-when-downgrade
SameOrigin
same-origin
Origin
origin
OriginWhenCrossOrigin
origin-when-cross-origin
UnsafeUrl
unsafe-url
StrictOrigin
strict-origin
StrictOriginWhenCrossOrigin
strict-origin-when-cross-origin