pub struct ContentLength(pub u64);
Content-Length header, defined in RFC7230

When a message does not have a Transfer-Encoding header field, a Content-Length header field can provide the anticipated size, as a decimal number of octets, for a potential payload body. For messages that do include a payload body, the Content-Length field-value provides the framing information necessary for determining where the body (and message) ends. For messages that do not include a payload body, the Content-Length indicates the size of the selected representation.

ABNF

Content-Length = 1*DIGIT

Example values

  • 3495

Example

use cogo_http::header::{Headers, ContentLength};
 
let mut headers = Headers::new();
headers.set(ContentLength(1024u64));

Tuple Fields

0: u64