The Host header.
HTTP/1.1 requires that all requests include a Host header, and so hyper
client requests add one automatically.
Currently is just a String, but it should probably become a better type,
like url::Host or something.
use cogo_http::header::{Headers, Host};
let mut headers = Headers::new();
headers.set(
Host{
hostname: "hyper.rs".to_owned(),
port: None,
}
);
use cogo_http::header::{Headers, Host};
let mut headers = Headers::new();
headers.set(
Host{
hostname: "hyper.rs".to_owned(),
port: Some(8080),
}
);
The hostname, such a example.domain.
Performs copy-assignment from source. Read more
Formats the value using the given formatter. Read more
Formats the value using the given formatter. Read more
The associated error which can be returned from parsing.
Parses a string s to return a value of this type. Read more
Returns the name of the header field this belongs to. Read more
Parse a header from a raw stream of bytes. Read more
Format a header to be output into a TcpStream. Read more
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
impl<T, U> Into<U> for T where
U: From<T>,
The alignment of pointer.
The type for initializers.
Initializes a with the given initializer. Read more
Mutably dereferences the given pointer. Read more
Drops the object pointed to by the given pointer. Read more
The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning. Read more
🔬 This is a nightly-only experimental API. (toowned_clone_into)
Uses borrowed data to replace owned data, usually by cloning. Read more
Converts the given value to a String. Read more
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.
Get the TypeId of this object.
impl<V, T> VZip<V> for T where
V: MultiLane<T>,