pub struct Origin {
pub scheme: String,
pub host: Host,
}
The Origin header.
The Origin header is a version of the Referer header that is used for all HTTP fetches and POSTs whose CORS flag is set.
This header is often used to inform recipients of the security context of where the request was initiated.
Following the spec, https://fetch.spec.whatwg.org/#origin-header, the value of this header is composed of
a String (scheme), header::Host (host/port)
use cogo_http::header::{Headers, Origin};
let mut headers = Headers::new();
headers.set(
Origin::new("http", "hyper.rs", None)
);
use cogo_http::header::{Headers, Origin};
let mut headers = Headers::new();
headers.set(
Origin::new("https", "wikipedia.org", Some(443))
);
The scheme, such as http or https
The host, such as Host{hostname: “hyper.rs”.to_owned(), port: None}
Creates a new Origin header.
Performs copy-assignment from source. Read more
Formats the value using the given formatter. Read more
Formats the value using the given formatter. Read more
The associated error which can be returned from parsing.
Parses a string s to return a value of this type. Read more
Returns the name of the header field this belongs to. Read more
Parse a header from a raw stream of bytes. Read more
Format a header to be output into a TcpStream. Read more
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
impl<T, U> Into<U> for T where
U: From<T>,
The alignment of pointer.
The type for initializers.
Initializes a with the given initializer. Read more
Mutably dereferences the given pointer. Read more
Drops the object pointed to by the given pointer. Read more
The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning. Read more
🔬 This is a nightly-only experimental API. (toowned_clone_into)
Uses borrowed data to replace owned data, usually by cloning. Read more
Converts the given value to a String. Read more
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.
Get the TypeId of this object.
impl<V, T> VZip<V> for T where
V: MultiLane<T>,