pub struct Listening {
    pub socket: SocketAddr,
    /* private fields */
}
A listening server, which can later be closed.

Fields

socket: SocketAddr

The socket addresses that the server is bound to.

Implementations

Warning: This function doesn’t work. The server remains listening after you called it. See https://github.com/hyperium/hyper/issues/338 for more details.

Stop the server from listening to its socket address.