pub struct RequestBuilder<'a> { /* private fields */ }
Options for an individual Request.
One of these will be built for you if you use one of the convenience
methods, such as get(), post(), etc.
Set a request body to be sent.
Add additional headers to the request.
Add an individual new header to the request.
Execute this request and receive a Response back.
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
impl<T, U> Into<U> for T where
U: From<T>,
The alignment of pointer.
The type for initializers.
Initializes a with the given initializer. Read more
Mutably dereferences the given pointer. Read more
Drops the object pointed to by the given pointer. Read more
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.
Get the TypeId of this object.
impl<V, T> VZip<V> for T where
V: MultiLane<T>,