pub struct Listening {
pub socket: SocketAddr,
/* private fields */
}
A listening server, which can later be closed.
The socket addresses that the server is bound to.
Warning: This function doesn’t work. The server remains listening after you called
it. See https://github.com/hyperium/hyper/issues/338 for more details.
Stop the server from listening to its socket address.
Formats the value using the given formatter. Read more
Executes the destructor for this type. Read more
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
impl<T, U> Into<U> for T where
U: From<T>,
The alignment of pointer.
The type for initializers.
Initializes a with the given initializer. Read more
Mutably dereferences the given pointer. Read more
Drops the object pointed to by the given pointer. Read more
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.
Get the TypeId of this object.
impl<V, T> VZip<V> for T where
V: MultiLane<T>,